@@ -13,7 +13,7 @@ class ModelDescriptionFieldSerializer(Serializer):
     verbose_name = fields_.CharField(required=False)
     required = fields_.BooleanField(required=False)
     default_type = fields_.CharField(required=False)
-    default_value = fields_.AnyField(required=False)
+    default_value = fields_.RawField(required=False)
 
 
 # class ModelDescriptionRelationSerializer(Serializer):
